"""
Audible Reminder

The Audible Reminder is a device to remind you that a machine is running.

The Audible Reminder plays a tone every few minutes to alert you it is on. The output
to the speaker is pin 1 or GP0  and a ground pin. A small inline resistor is probably helpful. It
can be inline with either wire.

The Audible Reminder blinks every second to remind you the machine is running.

For a computer, all is required is to plug it into a USB power port on the machine.
it will run independently of the device.

For none computer applications you can power the Audible Reminder from a USB power
source that is switched with the machine. It will beep using the given parameters
as long as it us under power.

The tone is detemined by the length of the "hold" variable

The how often you want to be reminded the machine is on in seconds is the
variable "reminder"  - 120 to 300 seconds works well. It you spend a great deal of
time in your shop, longer intervals are effective in reminding you your equipment
is still running.

You can simply use the (Beep(tone_freqency)" command passing the "hold"
variable as the tone_freqency. It starts in the midrange (0.001) and
gets lower (0.002-0.012)

You can also pass dots and dashes to identify the machine left on -
I used U for Unisaw - dot-dot-dash

You don't need to know Morse code to use it, it simply makes a unique
pattern for each machine that you will come to identify and accually some
learn Morse Code against your will.

Morse code:
A	• ─	
B	─ • • •	
C	─ • ─ •	
D	─ • •	
E	•	
F	• • ─ •	
G	─ ─ •	
H	• • • •	
I	• •	
J	• ─ ─ ─	
K	─ • ─	
L	• ─ • •	
M	─ ─	
N	─ •	
O	─ ─ ─	
P	• ─ ─ •	
Q	─ ─ • ─	
R	• ─ •	
S	• • •	
T	─	
U	• • ─	
V	• • • ─	
W	• ─ ─	
X	─ • • ─	
Y	─ • ─ ─	
Z	─ ─ • •
"""

import board  # core module in circuit python on Feather RP2040
import digitalio  # core module in circuit python on Feather RP2040
import time  # core module in circuit python on Feather RP2040

# identfy the pinouts on the PICO for speaker output
beep = digitalio.DigitalInOut(board.GP0)
beep.direction = digitalio.Direction.OUTPUT


# Ready LED
led = digitalio.DigitalInOut(board.LED)
led.direction = digitalio.Direction.OUTPUT


# define hold which will determine the pitch of the tone
hold = .001
# define the number of seconds between audible tones
reminder = 180

def Blink(reminder):
    n = reminder
    while n != 0:
        led.value = True
        time.sleep(.5)
        led.value = False
        time.sleep(.5)
        n = n - 1
    return

def Beep(hold):
    n = 100
    while n != 0:
        beep.value = True
        time.sleep(hold)
        beep.value = False
        time.sleep(hold)
        n = n - 1
    return

def Dot(hold):
    n = 33
    time.sleep(.3)
    while n != 0:
        beep.value = True
        time.sleep(hold)
        beep.value = False
        time.sleep(hold)
        n = n - 1
    return

def Dash(hold):
    n = 130
    time.sleep(.3)
    while n != 0:
        beep.value = True
        time.sleep(hold)
        beep.value = False
        time.sleep(hold)
        n = n - 1

    return

while True:
    # reminder is the number of seconds to pause while the LED blinks
    Blink(reminder)
    # turn on LED
    led.value = True
    # unisaw designator will be 'U' in Morse code: . . _
    # here we go Dot Dot Dash
    Dot(hold)
    Dot(hold)
    Dash(hold)
    # turn off LED
    led.value = False


